@@ -17,6 +17,7 @@ class SettingsDialog(QDialog):
         self.setupAutosave()
 
     def initWidgets(self):
+        self.bar = QStatusBar()
         self.allow_editing = QCheckBox("Allow directly editing of text fields")
         self.lemmatization = QCheckBox("Use lemmatization (Requires restart to take effect)")
         self.lemmatization.setToolTip("Lemmatization means to get the original form of words."
@@ -39,6 +40,11 @@ class SettingsDialog(QDialog):
         self.definition2_field = QComboBox()
         self.pronunciation_field = QComboBox()
         self.forvo = QCheckBox("Play Forvo pronunciation upon word selection")
+        self.bold_word = QCheckBox("Bold word in sentence on lookup")
+        self.note_type_url = QLabel("For a suitable note type, \
+            download <a href=\"https://freelanguagetools.org/sample.apkg\">this file</a> \
+                and import it to your Anki collection.")
+        self.note_type_url.setOpenExternalLinks(True)
 
         self.web_preset = QComboBox()
         self.custom_url = QLineEdit()
@@ -62,13 +68,21 @@ class SettingsDialog(QDialog):
         self.text_scale_box_layout.addWidget(self.text_scale_label)
 
         self.orientation.addItems(["Vertical", "Horizontal"])
-
         self.anki_api = QLineEdit()
         self.about_sa = QScrollArea()
-        self.host = QLineEdit()
-        self.port = QSpinBox()
-        self.port.setMinimum(1024)
-        self.port.setMaximum(49151)
+
+        self.api_enabled = QCheckBox("Enable SSM local API")
+        self.api_host = QLineEdit()
+        self.api_port = QSpinBox()
+        self.api_port.setMinimum(1024)
+        self.api_port.setMaximum(49151)
+
+        self.reader_enabled = QCheckBox("Enable SSM Web Reader")
+        self.reader_host = QLineEdit()
+        self.reader_port = QSpinBox()
+        self.reader_port.setMinimum(1024)
+        self.reader_port.setMaximum(49151)
+
         self.importdict = QPushButton('Manage local dictionaries..')
 
         self.about = QLabel(
@@ -78,19 +92,20 @@ Visit <a href="https://freelanguagetools.org">FreeLanguageTools.org</a> for more
 You can also talk to us on <a href="https://webchat.kde.org/#/room/#flt:midov.pl">Matrix</a>
 or <a href="https://t.me/fltchat">Telegram</a> for support.<br><br>
 
-Simple Sentence Mining (SSM, ssmtool) is free software available under the terms of
-<a href="https://www.gnu.org/licenses/gpl-3.0.en.html">GNU GPLv3</a>.<br><br>
-If you found a bug, or have enhancement ideas, 
-feel free to open an issue on the 
-Github <a href=https://github.com/FreeLanguageTools/ssmtool>repository</a>.<br><br>
+Consult <a href="https://freelanguagetools.org/2021/08/dictionaries-and-frequency-lists-for-ssm/">this link</a> 
+to find compatible dictionaries. <br><br>
 
+Simple Sentence Mining (SSM, ssmtool) is free software available to you under the terms of
+<a href="https://www.gnu.org/licenses/gpl-3.0.en.html">GNU GPLv3</a>.
+If you found a bug, or have enhancement ideas, please open an issue on the 
+Github <a href=https://github.com/FreeLanguageTools/ssmtool>repository</a>.<br><br>
 
 This program is yours to keep. There is no EULA you need to agree to.
 No data is sent to any server other than the configured dictionary APIs.
 Statistics data are stored locally.
 <br><br>
 Credits: <br><a href="https://en.wiktionary.org/wiki/Wiktionary:Main_Page">Wiktionary API</a><br>
-If you find this tool useful, you can donate to these projects.
+If you find this tool useful, you can give it a star on Github and tell others about it. Any suggestions will also be appreciated.
             '''
         )
         self.about.setTextFormat(Qt.RichText)
@@ -98,11 +113,16 @@ If you find this tool useful, you can donate to these projects.
         self.about_sa.setWidget(self.about)
         self.about.setWordWrap(True)
         self.about.adjustSize()
+        
         self.importdict.clicked.connect(self.dictmanager)
 
     def dictmanager(self):
         importer = DictManager(self)
         importer.exec()
+        self.loadDictionaries()
+        self.loadDict2Options()
+        self.loadFreqSources()
+        self.syncSettings()
     
     def initTabs(self):
         self.tabs = QTabWidget()
@@ -121,10 +141,11 @@ If you find this tool useful, you can donate to these projects.
 
         self.layout = QVBoxLayout(self)
         self.layout.addWidget(self.tabs)
+        self.layout.addWidget(self.bar)
 
         self.tabs.addTab(self.tab1, "Dictionary")
         self.tabs.addTab(self.tab2, "Anki")
-        self.tabs.addTab(self.tab3, "API")
+        self.tabs.addTab(self.tab3, "Network")
         self.tabs.addTab(self.tab4, "Interface")
         self.tabs.addTab(self.tab5, "About")
 
@@ -141,6 +162,7 @@ If you find this tool useful, you can donate to these projects.
         
         self.tab1.layout.addRow(self.lemmatization)
         self.tab1.layout.addRow(self.lemfreq)
+        self.tab1.layout.addRow(self.bold_word)
         self.tab1.layout.addRow(self.forvo)
         self.tab1.layout.addRow(QLabel("Target language"), self.target_language)
         self.tab1.layout.addRow(QLabel("Dictionary source 1"), self.dict_source)
@@ -161,10 +183,15 @@ If you find this tool useful, you can donate to these projects.
         self.tab2.layout.addRow(QLabel('Field name for "Definition"'), self.definition_field)
         self.tab2.layout.addRow(QLabel('Field name for "Definition#2"'), self.definition2_field)
         self.tab2.layout.addRow(QLabel('Field name for "Pronunciation"'), self.pronunciation_field)
+        self.tab2.layout.addRow(self.note_type_url)
 
-        self.tab3.layout.addRow(QLabel('<i>Most users should not need to change these settings.</i>'))
-        self.tab3.layout.addRow(QLabel("API host"), self.host)
-        self.tab3.layout.addRow(QLabel("API port"), self.port)
+        self.tab3.layout.addRow(QLabel('<i>Most users should not need to change these settings.</i><br><b>All settings on this tab requires restart to take effect.</b>'))
+        self.tab3.layout.addRow(self.api_enabled)
+        self.tab3.layout.addRow(QLabel("API host"), self.api_host)
+        self.tab3.layout.addRow(QLabel("API port"), self.api_port)
+        self.tab3.layout.addRow(self.reader_enabled)
+        self.tab3.layout.addRow(QLabel("Web reader host"), self.reader_host)
+        self.tab3.layout.addRow(QLabel("Web reader port"), self.reader_port)
 
         self.tab4.layout.addRow(QLabel("<b>All settings on this tab requires restart to take effect.</b>"))
         self.tab4.layout.addRow(self.allow_editing)
@@ -183,6 +210,7 @@ If you find this tool useful, you can donate to these projects.
         self.lemmatization.clicked.connect(self.syncSettings)
         self.lemfreq.clicked.connect(self.syncSettings)
         self.forvo.clicked.connect(self.syncSettings)
+        self.bold_word.clicked.connect(self.syncSettings)
         self.freq_source.currentTextChanged.connect(self.syncSettings)
         self.dict_source.currentTextChanged.connect(self.syncSettings)
         self.dict_source.currentTextChanged.connect(self.loadDict2Options)
@@ -213,16 +241,30 @@ If you find this tool useful, you can donate to these projects.
         self.pronunciation_field.currentTextChanged.connect(self.checkCorrectness)
         self.anki_api.editingFinished.connect(self.syncSettings)
         self.anki_api.editingFinished.connect(self.loadSettings)
-        self.host.textChanged.connect(self.syncSettings)
-        self.port.valueChanged.connect(self.syncSettings)
+        self.api_enabled.clicked.connect(self.setAvailable)
+        self.api_enabled.clicked.connect(self.syncSettings)
+        self.api_host.editingFinished.connect(self.syncSettings)
+        self.api_port.valueChanged.connect(self.syncSettings)
+        self.reader_enabled.clicked.connect(self.setAvailable)
+        self.reader_enabled.clicked.connect(self.syncSettings)
+        self.reader_host.editingFinished.connect(self.syncSettings)
+        self.reader_port.valueChanged.connect(self.syncSettings)
         self.text_scale.valueChanged.connect(self.syncSettings)
         self.orientation.currentTextChanged.connect(self.syncSettings)
 
+    def setAvailable(self):
+        self.api_host.setEnabled(self.api_enabled.isChecked())
+        self.api_port.setEnabled(self.api_enabled.isChecked())
+        self.reader_host.setEnabled(self.reader_enabled.isChecked())
+        self.reader_port.setEnabled(self.reader_enabled.isChecked())
+
     def loadDictionaries(self):
         custom_dicts = self.settings.value("custom_dicts", [], type=list)
+        self.dict_source.blockSignals(True)
         self.dict_source.clear()
         dicts = getDictsForLang(code[self.target_language.currentText()], custom_dicts)
         self.dict_source.addItems(dicts)
+        self.dict_source.blockSignals(False)
 
     def loadDict2Options(self):
         custom_dicts = self.settings.value("custom_dicts", [], type=list)
@@ -242,10 +284,13 @@ If you find this tool useful, you can donate to these projects.
     def loadFreqSources(self):
         custom_dicts = self.settings.value("custom_dicts", [], type=list)
         sources = getFreqlistsForLang(code[self.target_language.currentText()], custom_dicts)
+        self.freq_source.blockSignals(True)
         self.freq_source.clear()
         self.freq_source.addItem("Disabled")
         for item in sources:
             self.freq_source.addItem(item)
+        self.freq_source.setCurrentText(self.settings.value("freq_source", "Disabled"))
+        self.freq_source.blockSignals(False)
 
     def loadUrl(self):
         langfull = self.settings.value("target_language", "English")
@@ -268,6 +313,7 @@ If you find this tool useful, you can donate to these projects.
 
     def loadSettings(self):
         self.forvo.setChecked(self.settings.value("forvo", False, type=bool))
+        self.bold_word.setChecked(self.settings.value("bold_word", True, type=bool))
         self.allow_editing.setChecked(self.settings.value("allow_editing", True, type=bool))
         self.lemmatization.setChecked(self.settings.value("lemmatization", True, type=bool))
         self.lemfreq.setChecked(self.settings.value("lemfreq", False, type=bool))
@@ -281,15 +327,18 @@ If you find this tool useful, you can donate to these projects.
         self.loadFreqSources()
         self.web_preset.setCurrentText(self.settings.value("web_preset", "English Wiktionary"))
         self.loadUrl()
-        self.freq_source.setCurrentText(self.settings.value("freq_source", "Disabled"))
         self.gtrans_lang.setCurrentText(self.settings.value("gtrans_lang", "English"))
         self.anki_api.setText(self.settings.value("anki_api", "http://localhost:8765"))
         self.tags.setText(self.settings.value("tags", "ssmtool"))
         api = self.anki_api.text()
         self.web_preset.setCurrentText(self.settings.value("web_preset"))
 
-        self.host.setText(self.settings.value("host", "127.0.0.1"))
-        self.port.setValue(self.settings.value("port", 39284, type=int))
+        self.api_enabled.setChecked(self.settings.value("api_enabled", True, type=bool))
+        self.api_host.setText(self.settings.value("host", "127.0.0.1"))
+        self.api_port.setValue(self.settings.value("port", 39284, type=int))
+        self.reader_enabled.setChecked(self.settings.value("reader_enabled", True, type=bool))
+        self.reader_host.setText(self.settings.value("reader_host", "127.0.0.1"))
+        self.reader_port.setValue(self.settings.value("reader_port", 39285, type=int))
 
         try:
             _ = getVersion(api)
@@ -298,17 +347,22 @@ If you find this tool useful, you can donate to these projects.
             return
 
         decks = getDeckList(api)
+        self.deck_name.blockSignals(True)
         self.deck_name.clear()
         self.deck_name.addItems(decks)
         self.deck_name.setCurrentText(self.settings.value("deck_name"))
+        self.deck_name.blockSignals(False)
 
         note_types = getNoteTypes(api)
+        self.note_type.blockSignals(True)
         self.note_type.clear()
         self.note_type.addItems(note_types)
         self.note_type.setCurrentText(self.settings.value("note_type"))
+        self.note_type.blockSignals(False)
         self.loadFields()
 
     def loadFields(self):
+        self.status("Loading fields")
         api = self.anki_api.text()
         try:
             _ = getVersion(api)
@@ -358,6 +412,7 @@ If you find this tool useful, you can donate to these projects.
         self.sentence_field.setCurrentText(self.settings.value("sentence_field"))
         self.word_field.setCurrentText(self.settings.value("word_field"))
         self.definition_field.setCurrentText(self.settings.value("definition_field"))
+        self.definition2_field.setCurrentText(self.settings.value("definition2_field"))
         self.pronunciation_field.setCurrentText(self.settings.value("pronunciation_field"))
 
         if self.sentence_field.findText(sent) != -1:
@@ -368,20 +423,23 @@ If you find this tool useful, you can donate to these projects.
             self.definition_field.setCurrentText(def1)
         if self.definition2_field.findText(def2) != -1:
             self.definition2_field.setCurrentText(def2)
-        if self.pronunciation_field.findText(def2) != -1:
-            self.pronunciation_field.setCurrentText(def2)
+        if self.pronunciation_field.findText(pron) != -1:
+            self.pronunciation_field.setCurrentText(pron)
         
         self.sentence_field.blockSignals(False)
         self.word_field.blockSignals(False)
         self.definition_field.blockSignals(False)
         self.definition2_field.blockSignals(False)
         self.pronunciation_field.blockSignals(False)
+        self.status("Done")
 
     def syncSettings(self):
+        self.status("Syncing")
         self.settings.setValue("forvo", self.forvo.isChecked())
         self.settings.setValue("allow_editing", self.allow_editing.isChecked())
         self.settings.setValue("lemmatization", self.lemmatization.isChecked())
         self.settings.setValue("lemfreq", self.lemfreq.isChecked())
+        self.settings.setValue("bold_word", self.bold_word.isChecked())
         self.settings.setValue("orientation", self.orientation.currentText())
         self.settings.setValue("target_language", self.target_language.currentText())
         self.settings.setValue("dict_source", self.dict_source.currentText())
@@ -389,8 +447,12 @@ If you find this tool useful, you can donate to these projects.
         self.settings.setValue("freq_source", self.freq_source.currentText())
         self.settings.setValue("gtrans_lang", self.gtrans_lang.currentText())
         self.settings.setValue("anki_api", self.anki_api.text())
-        self.settings.setValue("host", self.host.text())
-        self.settings.setValue("port", self.port.value())
+        self.settings.setValue("api_enabled", self.api_enabled.isChecked())
+        self.settings.setValue("host", self.api_host.text())
+        self.settings.setValue("port", self.api_port.value())
+        self.settings.setValue("reader_enabled", self.reader_enabled.isChecked())
+        self.settings.setValue("reader_host", self.reader_host.text())
+        self.settings.setValue("reader_port", self.reader_port.value())
         self.settings.setValue("text_scale", self.text_scale.value())
         self.settings.setValue("web_preset", self.web_preset.currentText())
         self.settings.setValue("custom_url", self.custom_url.text())
@@ -408,6 +470,7 @@ If you find this tool useful, you can donate to these projects.
         except Exception as e:
             pass
         self.settings.sync()
+        self.status("Settings saved")
     
     def errorNoConnection(self, error):
         msg = QMessageBox()
@@ -435,4 +498,7 @@ If you find this tool useful, you can donate to these projects.
             self.definition_field.currentText(), self.definition2_field.currentText()]
 
         if len(set(set_fields)) != len(set_fields):
-            self.warn("All fields must be set to different note fields.\nYou *will* encounter bugs.")
\ No newline at end of file
+            self.warn("All fields must be set to different note fields.\nYou *will* encounter bugs.")
+
+    def status(self, msg):
+        self.bar.showMessage(self.parent.time() + " " + msg, 4000)
\ No newline at end of file
